@@ -167,6 +167,8 @@ typedef struct single {
    const char *name;		/* only with END_UNLINK */
    int (*sigchild)(struct single *);	/* callback after sigchild */
    pid_t ppid;			/* parent pid, only if we send it signals */
+   int escape;			/* escape character; -1 for no escape */
+   bool actescape;		/* escape character found in input data */
    union {
       struct {
 	 int fdout;		/* use fd for output */
@@ -177,7 +179,7 @@ typedef struct single {
 	 union sockaddr_union la;	/* local socket address */
 	 bool emptyiseof;	/* with dgram: empty packet means EOF */
 	 bool dorange;
-	 union xiorange_union range;	/* restrictions for peer address */
+	 struct xiorange range;	/* restrictions for peer address */
 #if _WITH_IP4 || _WITH_IP6
 	 struct {
 	    unsigned int res_opts[2];	/* bits to be set in _res.options are
@@ -333,7 +335,7 @@ union integral {
    } u_ip_mreq;
 #endif
 #if WITH_IP4
-   in_addr_t  u_ip4addr;
+   struct in_addr  u_ip4addr;
 #endif
 } ;
 
@@ -355,6 +357,8 @@ union integral {
 struct opt {
    const struct optdesc *desc;
    union integral value;
+   union integral value2;
+   union integral value3;
 } ;
 
 extern const char *PIPESEP;
@@ -373,6 +377,8 @@ extern xiofile_t *sock[XIO_MAXSOCK];
 				   not even by external changes correctable */
 
 extern int xioinitialize(void);
+extern int xioinitialize2(void);
+extern pid_t xio_fork(bool subchild, int level);
 extern int xio_forked_inchild(void);
 extern int xiosetopt(char what, const char *arg);
 extern int xioinqopt(char what, char *arg, size_t n);
